@@ -1,3 +1,8 @@
+use ockam_core::{
+    errcode::{Kind, Origin},
+    Error,
+};
+
 #[derive(Clone, Copy, Debug)]
 pub enum IdentityError {
     BareError = 1,
@@ -41,18 +46,18 @@ pub enum IdentityError {
     VerifierInvalidMessage,
 }
 
-impl IdentityError {
-    /// Integer code associated with the error domain.
-    pub const DOMAIN_CODE: u32 = 20_000;
-    /// Descriptive name for the error domain.
-    pub const DOMAIN_NAME: &'static str = "OCKAM_ENTITY";
+impl ockam_core::compat::error::Error for IdentityError {}
+impl core::fmt::Display for IdentityError {
+    fn fmt(&self, f: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
+        core::fmt::Debug::fmt(self, f)
+    }
 }
 
-impl From<IdentityError> for ockam_core::Error {
-    fn from(e: IdentityError) -> ockam_core::Error {
-        ockam_core::Error::new(
-            IdentityError::DOMAIN_CODE + (e as u32),
-            ockam_core::compat::format!("{}::{:?}", module_path!(), e),
-        )
+impl From<IdentityError> for Error {
+    #[track_caller]
+    fn from(err: IdentityError) -> Self {
+        let kind = Kind::Unknown; // FIXME: fill these in with more
+                                  // meaningful error kinds
+        Error::new(Origin::Identity, kind, err)
     }
 }
