@@ -10,7 +10,7 @@ pub struct IdentityBuilder<V: IdentityVault> {
 
 impl<V: IdentityVault> IdentityBuilder<V> {
     pub async fn new(ctx: &Context, vault: &V) -> Result<Self> {
-        let child_ctx = ctx.new_context(Address::random(0)).await?;
+        let child_ctx = ctx.new_context(Address::random_local()).await?;
 
         Ok(Self {
             ctx: child_ctx,
@@ -26,7 +26,7 @@ impl<V: IdentityVault> IdentityBuilder<V> {
 #[cfg(test)]
 mod test {
     use crate::IdentityBuilder;
-    use ockam_vault_sync_core::Vault;
+    use ockam_vault::Vault;
 
     #[test]
     fn test_builder() {
